# Generated by Django 4.1.7 on 2023-06-04 12:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('project_center', '0010_delete_activity_project_last_activity_date_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='last_activity_name',
            field=models.CharField(blank=True, default=None, help_text='Last Activity Name', max_length=255, null=True, verbose_name='Last Activity Name'),
        ),
    ]



# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

REQUIREMENTS = [
]

# https://pypi.python.org/pypi?%3Aaction=list_classifiers
CLASSIFIERS = []

setup(
    name='django-project-center',
    version='0.8',
    description='Project Management Module for Django',
    author='siteshell.net',
    author_email='pdbethke@siteshell.net',
    url='https://github.com/pdbethke/django-project-center',
    packages=find_packages(),
    license='LICENSE.txt',
    platforms=['OS Independent'],
    install_requires=REQUIREMENTS,
    classifiers=CLASSIFIERS,
    long_description_content_type='text/markdown',
    long_description=open('README.md').read(),
    include_package_data=True,
    zip_safe=False,
    # test_suite="test_settings.run",
)